recip: Package for Igusa class polynomials, CM fields, and Shimura's reciprocity law
====================================================================================

Description
-----------

Package for Igusa class polynomials, CM fields, and Shimura's reciprocity law

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/recip/
